#!/bin/bash -e
# Copyright (C) 2020 Konstantin Tokarev <annulen@yandex.ru>
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
# BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
# THE POSSIBILITY OF SUCH DAMAGE.

usage() {
    echo "Usage: $0 <qt_ref>"
    echo "    where qt_ref is tag or other git reference from qt5.git repo to take submodules from"
    exit 0
}

if [ -z "$1" ]; then
    usage
fi

if [ "$1" = "--help" ]; then
    usage
fi

QT_REF="$1"
SCRIPTNAME=$(basename "$0")

for m in qt*; do
    if [ -d "$m" ]; then
        case "$m" in
        qtbase|qtdeclarative|qtlocation|qtmultimedia|qtsensors|qtwebchannel)
            if [ -n "$QT_REF" ]; then
                echo "Checking out '$QT_REF' in $m"
                git checkout -q "$QT_REF" "$m"
            else
                echo "Keeping '$m'"
            fi
            ;;
        *)
            git rm "$m";;
        esac
    fi
done
git commit -m "*** AUTOGENERATED COMMIT ***

Remove Qt modules not used in QtWebKit.
This commit was generated by ${SCRIPTNAME}.
"
